@@ -276,7 +276,11 @@ public class SampleFamily {
         return SampleFamily.build(
             this.context,
             Arrays.stream(samples)
-                  .map(sample -> sample.increase(range, (lowerBoundValue, unused) -> sample.value - lowerBoundValue))
+                  .map(sample -> sample.increase(
+                      range,
+                      context.metricName,
+                      (lowerBoundValue, unused) -> sample.value - lowerBoundValue
+                  ))
                   .toArray(Sample[]::new)
         );
     }
@@ -291,6 +295,7 @@ public class SampleFamily {
             Arrays.stream(samples)
                   .map(sample -> sample.increase(
                       range,
+                      context.metricName,
                       (lowerBoundValue, lowerBoundTime) -> {
                           final long timeDiff = (sample.timestamp - lowerBoundTime) / 1000;
                           return timeDiff < 1L ? 0.0 : (sample.value - lowerBoundValue) / timeDiff;
@@ -308,6 +313,7 @@ public class SampleFamily {
             this.context,
             Arrays.stream(samples)
                   .map(sample -> sample.increase(
+                      context.metricName,
                       (lowerBoundValue, lowerBoundTime) -> {
                           final long timeDiff = (sample.timestamp - lowerBoundTime) / 1000;
                           return timeDiff < 1L ? 0.0 : (sample.value - lowerBoundValue) / timeDiff;
@@ -637,7 +643,7 @@ public class SampleFamily {
      * The parsing context holds key results more than sample collection.
      */
     @ToString
-    @EqualsAndHashCode
+    @EqualsAndHashCode(exclude = "metricName")
     @Getter
     @Setter
     @Builder
@@ -651,6 +657,8 @@ public class SampleFamily {
                                  .build();
         }
 
+        private String metricName;
+
         @Builder.Default
         private Map<MeterEntity, Sample[]> meterSamples = new HashMap<>();
 
