@@ -157,7 +157,7 @@ public class AggregationTest {
                      String expression,
                      Result want,
                      boolean isThrow) {
-        Expression e = DSL.parse(expression);
+        Expression e = DSL.parse(name, expression);
         Result r = null;
         try {
             r = e.run(input);
