@@ -21,8 +21,12 @@ package org.apache.skywalking.oap.server.core.alarm.provider;
 import org.apache.skywalking.apm.network.event.v3.Event;
 import org.apache.skywalking.oap.server.analyzer.event.EventAnalyzerService;
 import org.apache.skywalking.oap.server.analyzer.event.EventAnalyzerServiceImpl;
+import org.apache.skywalking.oap.server.core.CoreModule;
 import org.apache.skywalking.oap.server.core.alarm.AlarmMessage;
 import org.apache.skywalking.oap.server.core.analysis.IDManager;
+import org.apache.skywalking.oap.server.core.analysis.Layer;
+import org.apache.skywalking.oap.server.core.query.MetadataQueryService;
+import org.apache.skywalking.oap.server.core.query.type.Service;
 import org.apache.skywalking.oap.server.core.source.DefaultScopeDefine;
 import org.apache.skywalking.oap.server.library.module.ModuleManager;
 import org.apache.skywalking.oap.server.library.module.ModuleProviderHolder;
@@ -52,6 +56,8 @@ public class EventHookCallbackTest {
 
     private EventAnalyzerService eventAnalyzerService = mock(EventAnalyzerServiceImpl.class);
 
+    private MetadataQueryService metadataQueryService = mock(MetadataQueryService.class);
+
     @Test
     public void testEventCallbackHasRightFlow() throws Exception {
         List<AlarmMessage> msgs = mockAlarmMessagesHasSingleElement();
@@ -59,7 +65,9 @@ public class EventHookCallbackTest {
         when(moduleManager.find("event-analyzer")).thenReturn(moduleProviderHolder);
         when(moduleProviderHolder.provider()).thenReturn(moduleServiceHolder);
         when(moduleServiceHolder.getService(EventAnalyzerService.class)).thenReturn(mockEventAnalyzerService);
-
+        when(moduleManager.find(CoreModule.NAME)).thenReturn(moduleProviderHolder);
+        when(moduleServiceHolder.getService(MetadataQueryService.class)).thenReturn(metadataQueryService);
+        when(metadataQueryService.getService(any())).thenReturn(mockService());
         //make sure current service be called.
         callback.doAlarm(msgs);
         verify(mockEventAnalyzerService).analyze(any(Event.class));
@@ -79,12 +87,15 @@ public class EventHookCallbackTest {
     }
 
     @Test
-    public void testRelationEventBeProperlyConstructed() {
+    public void testRelationEventBeProperlyConstructed() throws Exception {
         List<AlarmMessage> msgs = mockAlarmMessagesHasSourceAndDest();
         EventHookCallback callback = new EventHookCallback(this.moduleManager);
         when(moduleManager.find("event-analyzer")).thenReturn(moduleProviderHolder);
         when(moduleProviderHolder.provider()).thenReturn(moduleServiceHolder);
         when(moduleServiceHolder.getService(EventAnalyzerService.class)).thenReturn(eventAnalyzerService);
+        when(moduleManager.find(CoreModule.NAME)).thenReturn(moduleProviderHolder);
+        when(moduleServiceHolder.getService(MetadataQueryService.class)).thenReturn(metadataQueryService);
+        when(metadataQueryService.getService(any())).thenReturn(mockService());
         callback.doAlarm(msgs);
 
         ArgumentCaptor<Event> argument = ArgumentCaptor.forClass(Event.class);
@@ -123,6 +134,13 @@ public class EventHookCallbackTest {
         return Arrays.asList(msg);
     }
 
+    private Service mockService() {
+        Service service = new Service();
+        service.setName("test-skywalking");
+        service.getLayers().add(Layer.GENERAL.name());
+        return service;
+    }
+
     class MockEventAnalyzerService implements EventAnalyzerService {
 
         @Override
