@@ -194,11 +194,36 @@ public class CoreModuleConfig extends ModuleConfig {
      */
     private int httpMaxRequestHeaderSize = 8192;
 
+    /**
+     * The period of HTTP URI pattern recognition. Unit is second.
+     * @since 9.5.0
+     */
+    private int syncPeriodHttpUriRecognitionPattern = 10;
+
+    /**
+     * The training period of HTTP URI pattern recognition. Unit is second.
+     * @since 9.5.0
+     */
+    private int trainingPeriodHttpUriRecognitionPattern = 60;
+
     /**
      * The max number of HTTP URIs per service for further URI pattern recognition.
+     * @since 9.5.0
      */
     private int maxHttpUrisNumberPerService = 3000;
 
+    /**
+     * The UI menu should activate fetch interval, default 20s
+     */
+    private int uiMenuRefreshInterval = 20;
+
+    /**
+     * The service cache refresh interval, default 10s
+     */
+    @Setter
+    @Getter
+    private int serviceCacheRefreshInterval = 10;
+
     public CoreModuleConfig() {
         this.downsampling = new ArrayList<>();
     }
