@@ -56,7 +56,10 @@ public enum Layer {
 
     /**
      * Function as a Service
+     *
+     * Deprecated since 9.7.0. OpenFunction relative features are not maintained anymore.
      */
+    @Deprecated
     FAAS(5, true),
 
     /**
@@ -188,7 +191,29 @@ public enum Layer {
     /**
      * MongoDB is a document database. It stores data in a type of JSON format called BSON.
      */
-    MONGODB(30, true);
+    MONGODB(30, true),
+
+    /**
+     * Kafka is a distributed streaming platform that is used publish and subscribe to streams of records.
+     */
+    KAFKA(31, true),
+
+    /**
+     * Pulsar is a distributed pub-sub messaging platform that provides high-performance, durable messaging.
+     * It is used to publish and subscribe to streams of records.
+     * Pulsar supports scalable and fault-tolerant messaging, making it suitable for use in distributed systems.
+     */
+    PULSAR(32, true),
+
+    /**
+     * A scalable, fault-tolerant, and low-latency storage service optimized for real-time workloads.
+     */
+    BOOKKEEPER(33, true),
+
+    /**
+     * Nginx is an HTTP and reverse proxy server, a mail proxy server, and a generic TCP/UDP proxy server.
+     */
+    NGINX(34, true);
 
     private final int value;
     /**
