@@ -19,9 +19,11 @@
 package org.apache.skywalking.oap.server.core.storage.annotation;
 
 import java.lang.annotation.ElementType;
+import java.lang.annotation.Inherited;
 import java.lang.annotation.Retention;
 import java.lang.annotation.RetentionPolicy;
 import java.lang.annotation.Target;
+
 import org.apache.skywalking.oap.server.core.analysis.record.Record;
 
 /**
@@ -47,7 +49,7 @@ public @interface BanyanDB {
 
     /**
      * Series key is used to group time series data per metric of one entity in one place.
-     *
+     * <p>
      * For example,
      * ServiceA's traffic gauge, service call per minute, includes following timestamp values, then it should be sharded
      * by service ID
@@ -65,7 +67,6 @@ public @interface BanyanDB {
      * <p>
      * Only work with {@link Column}
      *
-     * @return non-negative if this column be used for sharding. -1 means not as a sharding key
      * @since 9.3.0 Rename as SeriesID.
      * @since 9.1.0 created as a new annotation.
      * @since 9.0.0 added in {@link Column}
@@ -75,8 +76,16 @@ public @interface BanyanDB {
     @interface SeriesID {
         /**
          * Relative entity tag
+         * <p>
+         * The index number determines the order of the column placed in the SeriesID.
+         * BanyanDB SeriesID searching procedure uses a prefix-scanning strategy.
+         * Searching series against a prefix could improve the performance.
+         * <p>
+         * For example, the ServiceTraffic composite "layer" and "name" as the SeriesID,
+         * considering OAP finds services by "layer", the "layer" 's index should be 0 to
+         * trigger a prefix-scanning.
          *
-         * @return index, from zero.
+         * @return non-negative if this column be used for sharding. -1 means not as a sharding key
          */
         int index() default -1;
     }
@@ -124,6 +133,7 @@ public @interface BanyanDB {
     /**
      * timestampColumn is to identify which column in {@link Record} is providing the timestamp(millisecond) for BanyanDB.
      * BanyanDB stream requires a timestamp in milliseconds.
+     *
      * @since 9.3.0
      */
     @Target({ElementType.TYPE})
@@ -131,4 +141,56 @@ public @interface BanyanDB {
     @interface TimestampColumn {
         String value();
     }
+
+    /**
+     * MeasureField defines a column as a measure's field.
+     * <p>
+     * Annotated: the column is a measure field.
+     * Unannotated: the column is a measure tag.
+     * storageOnly=true: the column is a measure tag that is not indexed.
+     * storageOnly=false: the column is a measure tag that is indexed.
+     * indexOnly=true: the column is a measure tag that is indexed, but not stored.
+     * indexOnly=false: the column is a measure tag that is indexed and stored.
+     *
+     * @since 9.4.0
+     */
+    @Target({ElementType.FIELD})
+    @Retention(RetentionPolicy.RUNTIME)
+    @interface MeasureField {
+    }
+
+    /**
+     * StoreIDTag indicates a metric store its ID as a tag for searching.
+     *
+     * @since 9.4.0
+     */
+    @Target({ElementType.TYPE})
+    @Retention(RetentionPolicy.RUNTIME)
+    @interface StoreIDAsTag {
+    }
+
+    /**
+     * Generate a TopN Aggregation and use the annotated column as a groupBy tag.
+     * It also contains parameters for TopNAggregation
+     *
+     * @since 9.4.0
+     */
+    @Target({ElementType.FIELD})
+    @Retention(RetentionPolicy.RUNTIME)
+    @Inherited
+    @interface TopNAggregation {
+        /**
+         * The size of LRU determines the maximally tolerated time range.
+         * The buffers in the time range are kept in the memory so that
+         * the data in [T - lruSize * n, T] would be accepted in the pre-aggregation process.
+         * T = the current time in the current dimensionality.
+         * n = interval in the current dimensionality.
+         */
+        int lruSize() default 2;
+
+        /**
+         * The max size of entries in a time window for the pre-aggregation.
+         */
+        int countersNumber() default 1000;
+    }
 }
