@@ -63,6 +63,12 @@ public class BanyanDBExtension {
     @Getter
     private final BanyanDB.IndexRule.IndexType indexType;
 
+    /**
+     *  A column belong to a measure's field.
+     */
+    @Getter
+    private final boolean isMeasureField;
+
     /**
      * @return true if this column is a part of sharding key
      */
