@@ -25,23 +25,32 @@ import com.linecorp.armeria.common.HttpStatus;
 import com.linecorp.armeria.server.Route;
 import com.linecorp.armeria.server.ServerBuilder;
 import com.linecorp.armeria.server.docs.DocService;
+import com.linecorp.armeria.server.encoding.DecodingService;
 import com.linecorp.armeria.server.healthcheck.HealthCheckService;
 import com.linecorp.armeria.server.logging.LoggingService;
+
+import java.io.FileInputStream;
+import java.io.IOException;
+import java.io.InputStream;
 import java.net.InetSocketAddress;
+
 import java.time.Duration;
 import java.util.List;
 import java.util.Set;
+
 import lombok.extern.slf4j.Slf4j;
 import org.apache.commons.lang3.StringUtils;
 import org.apache.skywalking.oap.server.library.server.Server;
+import org.apache.skywalking.oap.server.library.server.ssl.PrivateKeyUtil;
+
 import static java.util.Objects.requireNonNull;
 
 @Slf4j
 public class HTTPServer implements Server {
     private final HTTPServerConfig config;
-    private ServerBuilder sb;
+    protected ServerBuilder sb;
     // Health check service, supports HEAD, GET method.
-    private final Set<HttpMethod> allowedMethods = Sets.newHashSet(HttpMethod.HEAD);
+    protected final Set<HttpMethod> allowedMethods = Sets.newHashSet(HttpMethod.HEAD);
 
     public HTTPServer(HTTPServerConfig config) {
         this.config = config;
@@ -56,10 +65,6 @@ public class HTTPServer implements Server {
             .serviceUnder(contextPath + "/docs", DocService.builder().build())
             .service("/internal/l7check", HealthCheckService.of())
             .workerGroup(config.getMaxThreads())
-            .http(new InetSocketAddress(
-                config.getHost(),
-                config.getPort()
-            ))
             .http1MaxHeaderSize(config.getMaxRequestHeaderSize())
             .idleTimeout(Duration.ofMillis(config.getIdleTimeOut()))
             .decorator(Route.ofCatchAll(), (delegate, ctx, req) -> {
@@ -68,12 +73,32 @@ public class HTTPServer implements Server {
                 }
                 return delegate.serve(ctx, req);
             })
+            .decorator(DecodingService.newDecorator())
             .decorator(LoggingService.newDecorator());
-
+        if (config.isEnableTLS()) {
+            sb.https(new InetSocketAddress(
+                    config.getHost(),
+                    config.getPort()));
+            try (InputStream cert = new FileInputStream(config.getTlsCertChainPath());
+                 InputStream key = PrivateKeyUtil.loadDecryptionKey(config.getTlsKeyPath())) {
+                sb.tls(cert, key);
+            } catch (IOException e) {
+                throw new IllegalArgumentException(e);
+            }
+        } else {
+            sb.http(new InetSocketAddress(
+                    config.getHost(),
+                    config.getPort()
+            ));
+        }
         if (config.getAcceptQueueSize() > 0) {
             sb.maxNumConnections(config.getAcceptQueueSize());
         }
 
+        if (config.isAcceptProxyRequest()) {
+            sb.absoluteUriTransformer(this::transformAbsoluteURI);
+        }
+
         log.info("Server root context path: {}", contextPath);
     }
 
@@ -98,4 +123,14 @@ public class HTTPServer implements Server {
     public void start() {
         sb.build().start().join();
     }
+
+    private String transformAbsoluteURI(final String uri) {
+        if (uri.startsWith("https://")) {
+            return uri.substring(uri.indexOf("/", 8));
+        }
+        if (uri.startsWith("http://")) {
+            return uri.substring(uri.indexOf("/", 7));
+        }
+        return uri;
+    }
 }
