@@ -21,6 +21,7 @@ package org.apache.skywalking.oap.server.receiver.sharing.server;
 import java.util.Objects;
 import org.apache.logging.log4j.util.Strings;
 import org.apache.skywalking.oap.server.core.CoreModule;
+import org.apache.skywalking.oap.server.core.RunningMode;
 import org.apache.skywalking.oap.server.core.remote.health.HealthCheckServiceHandler;
 import org.apache.skywalking.oap.server.core.server.GRPCHandlerRegister;
 import org.apache.skywalking.oap.server.core.server.GRPCHandlerRegisterImpl;
@@ -85,6 +86,9 @@ public class SharingServerModuleProvider extends ModuleProvider {
             httpServerConfig.setPort(config.getRestPort());
             httpServerConfig.setContextPath(config.getRestContextPath());
 
+            setBootingParameter("oap.external.http.host", config.getRestHost());
+            setBootingParameter("oap.external.http.port", config.getRestPort());
+
             httpServer = new HTTPServer(httpServerConfig);
             httpServer.initialize();
 
@@ -98,7 +102,7 @@ public class SharingServerModuleProvider extends ModuleProvider {
             authenticationInterceptor = new AuthenticationInterceptor(config.getAuthentication());
         }
 
-        if (config.getGRPCPort() != 0) {
+        if (config.getGRPCPort() != 0 && !RunningMode.isInitMode()) {
             if (config.isGRPCSslEnabled()) {
                 grpcServer = new GRPCServer(
                     Strings.isBlank(config.getGRPCHost()) ? "0.0.0.0" : config.getGRPCHost(),
@@ -113,6 +117,8 @@ public class SharingServerModuleProvider extends ModuleProvider {
                     config.getGRPCPort()
                 );
             }
+            setBootingParameter("oap.external.grpc.host", config.getGRPCHost());
+            setBootingParameter("oap.external.grpc.port", config.getGRPCPort());
             if (config.getMaxMessageSize() > 0) {
                 grpcServer.setMaxMessageSize(config.getMaxMessageSize());
             }
@@ -162,10 +168,10 @@ public class SharingServerModuleProvider extends ModuleProvider {
     @Override
     public void notifyAfterCompleted() throws ModuleStartException {
         try {
-            if (Objects.nonNull(grpcServer)) {
+            if (Objects.nonNull(grpcServer) && !RunningMode.isInitMode()) {
                 grpcServer.start();
             }
-            if (Objects.nonNull(httpServer)) {
+            if (Objects.nonNull(httpServer) && !RunningMode.isInitMode()) {
                 httpServer.start();
             }
         } catch (ServerException e) {
