@@ -18,12 +18,15 @@
 
 package org.apache.skywalking.oap.server.starter.config;
 
+import java.util.List;
+import lombok.Getter;
 import lombok.extern.slf4j.Slf4j;
 import org.apache.skywalking.oap.server.library.module.ApplicationConfiguration;
 import org.apache.skywalking.oap.server.library.module.ProviderNotFoundException;
 import org.apache.skywalking.oap.server.library.util.CollectionUtils;
 import org.apache.skywalking.oap.server.library.util.PropertyPlaceholderHelper;
 import org.apache.skywalking.oap.server.library.util.ResourceUtils;
+import org.apache.skywalking.oap.server.library.module.TerminalFriendlyTable;
 import org.yaml.snakeyaml.Yaml;
 
 import java.io.FileNotFoundException;
@@ -44,7 +47,16 @@ public class ApplicationConfigLoader implements ConfigLoader<ApplicationConfigur
     private static final String DISABLE_SELECTOR = "-";
     private static final String SELECTOR = "selector";
 
-    private final Yaml yaml = new Yaml();
+    private final TerminalFriendlyTable bootingParameters;
+    private final Yaml yaml;
+    @Getter
+    private final List<ApplicationConfiguration.ModuleConfiguration> resolvedConfigurations;
+
+    public ApplicationConfigLoader(final TerminalFriendlyTable bootingParameters) {
+        this.bootingParameters = bootingParameters;
+        this.yaml = new Yaml();
+        this.resolvedConfigurations = new ArrayList<>();
+    }
 
     @Override
     public ApplicationConfiguration load() throws ConfigFileNotFoundException {
@@ -71,6 +83,7 @@ public class ApplicationConfigLoader implements ConfigLoader<ApplicationConfigur
                                 "Get a provider define belong to {} module, provider name: {}", moduleName,
                                 providerName
                             );
+                            bootingParameters.addRow(new TerminalFriendlyTable.Row("module." + moduleName + ".provider", providerName));
                             final Map<String, ?> propertiesConfig = (Map<String, ?>) config;
                             final Properties properties = new Properties();
                             if (propertiesConfig != null) {
@@ -89,6 +102,7 @@ public class ApplicationConfigLoader implements ConfigLoader<ApplicationConfigur
                                 });
                             }
                             moduleConfiguration.addProviderConfiguration(providerName, properties);
+                            resolvedConfigurations.add(moduleConfiguration);
                         });
                     } else {
                         log.warn(
