@@ -25,7 +25,6 @@ import com.google.gson.JsonObject;
 import lombok.SneakyThrows;
 import org.apache.commons.lang3.StringUtils;
 import org.apache.skywalking.oap.server.core.analysis.IDManager;
-import org.apache.skywalking.oap.server.core.analysis.Layer;
 import org.apache.skywalking.oap.server.core.analysis.TimeBucket;
 import org.apache.skywalking.oap.server.core.analysis.manual.endpoint.EndpointTraffic;
 import org.apache.skywalking.oap.server.core.analysis.manual.instance.InstanceTraffic;
@@ -74,12 +73,12 @@ public class JDBCMetadataQueryDAO implements IMetadataQueryDAO {
 
     @Override
     @SneakyThrows
-    public List<Service> listServices(final String layer, final String group) {
+    public List<Service> listServices() {
         final var results = new ArrayList<Service>();
         final var tables = tableHelper.getTablesWithinTTL(ServiceTraffic.INDEX_NAME);
 
         for (final var table : tables) {
-            final var sqlAndParameters = buildSQLForListServices(layer, group, table);
+            final var sqlAndParameters = buildSQLForListServices(table);
             results.addAll(jdbcClient.executeQuery(
                 sqlAndParameters.sql(),
                 this::buildServices,
@@ -92,57 +91,13 @@ public class JDBCMetadataQueryDAO implements IMetadataQueryDAO {
             .collect(toList());
     }
 
-    protected SQLAndParameters buildSQLForListServices(String layer, String group, String table) {
+    protected SQLAndParameters buildSQLForListServices(String table) {
         final var sql = new StringBuilder();
         final var parameters = new ArrayList<>(5);
         sql.append("select * from ").append(table)
            .append(" where ").append(JDBCTableInstaller.TABLE_COLUMN).append(" = ? ");
         parameters.add(ServiceTraffic.INDEX_NAME);
 
-        if (StringUtil.isNotEmpty(layer)) {
-            sql.append(" and ").append(ServiceTraffic.LAYER).append(" = ?");
-            parameters.add(Layer.valueOf(layer).value());
-        }
-        if (StringUtil.isNotEmpty(group)) {
-            sql.append(" and ").append(ServiceTraffic.GROUP).append(" = ?");
-            parameters.add(group);
-        }
-
-        sql.append(" limit ").append(metadataQueryMaxSize);
-
-        return new SQLAndParameters(sql.toString(), parameters);
-    }
-
-    @Override
-    @SneakyThrows
-    public List<Service> getServices(final String serviceId) {
-        final var tables = tableHelper.getTablesWithinTTL(ServiceTraffic.INDEX_NAME);
-        final var results = new ArrayList<Service>();
-
-        for (String table : tables) {
-            final SQLAndParameters sqlAndParameters = buildSQLForGetServices(serviceId, table);
-            results.addAll(
-                jdbcClient.executeQuery(
-                    sqlAndParameters.sql(),
-                    this::buildServices,
-                    sqlAndParameters.parameters()
-                )
-            );
-        }
-        return results
-            .stream()
-            .limit(metadataQueryMaxSize)
-            .collect(toList());
-    }
-
-    protected SQLAndParameters buildSQLForGetServices(String serviceId, String table) {
-        final var sql = new StringBuilder();
-        final var parameters = new ArrayList<>(5);
-        sql.append("select * from ").append(table)
-           .append(" where ").append(JDBCTableInstaller.TABLE_COLUMN).append(" = ?")
-           .append(" and ").append(ServiceTraffic.SERVICE_ID).append(" = ?");
-        parameters.add(ServiceTraffic.INDEX_NAME);
-        parameters.add(serviceId);
         sql.append(" limit ").append(metadataQueryMaxSize);
 
         return new SQLAndParameters(sql.toString(), parameters);
@@ -154,16 +109,11 @@ public class JDBCMetadataQueryDAO implements IMetadataQueryDAO {
                                                String serviceId) {
         final var results = new ArrayList<ServiceInstance>();
 
-        final var minuteTimeBucket = TimeBucket.getMinuteTimeBucket(duration.getStartTimestamp());
-
-        final var tables = tableHelper.getTablesForRead(
-            InstanceTraffic.INDEX_NAME,
-            duration.getStartTimeBucket(),
-            duration.getEndTimeBucket()
-        );
-
+        final var startMinuteTimeBucket = TimeBucket.getMinuteTimeBucket(duration.getStartTimestamp());
+        final var endMinuteTimeBucket = TimeBucket.getMinuteTimeBucket(duration.getEndTimestamp());
+        final var tables = tableHelper.getTablesWithinTTL(InstanceTraffic.INDEX_NAME);
         for (String table : tables) {
-            final var sqlAndParameters = buildSQLForListInstances(serviceId, minuteTimeBucket, table);
+            final var sqlAndParameters = buildSQLForListInstances(serviceId, startMinuteTimeBucket, endMinuteTimeBucket, table);
             results.addAll(
                 jdbcClient.executeQuery(
                     sqlAndParameters.sql(),
@@ -179,7 +129,7 @@ public class JDBCMetadataQueryDAO implements IMetadataQueryDAO {
             .collect(toList());
     }
 
-    protected SQLAndParameters buildSQLForListInstances(String serviceId, long minuteTimeBucket, String table) {
+    protected SQLAndParameters buildSQLForListInstances(String serviceId, long minuteTimeBucket, long endMinuteTimeBucket, String table) {
         final var  sql = new StringBuilder();
         final var parameters = new ArrayList<>(5);
         sql.append("select * from ").append(table).append(" where ")
@@ -187,6 +137,8 @@ public class JDBCMetadataQueryDAO implements IMetadataQueryDAO {
         parameters.add(InstanceTraffic.INDEX_NAME);
         sql.append(" and ").append(InstanceTraffic.LAST_PING_TIME_BUCKET).append(" >= ?");
         parameters.add(minuteTimeBucket);
+        sql.append(" and ").append(InstanceTraffic.TIME_BUCKET).append(" < ?");
+        parameters.add(endMinuteTimeBucket);
         sql.append(" and ").append(InstanceTraffic.SERVICE_ID).append("=?");
         parameters.add(serviceId);
         sql.append(" limit ").append(metadataQueryMaxSize);
