@@ -19,8 +19,8 @@
 
  package org.apache.skywalking.generator;
 
-import static org.junit.Assert.assertEquals;
-import org.junit.Test;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import org.junit.jupiter.api.Test;
 
 public class IntGeneratorTest {
     @Test
